@@ -23,11 +23,18 @@ def get_netrc_file():
     
     return netrc_file, fname
 
-def clear_netrc():
+def clear_netrc(env):
     netrc_file, fname = get_netrc_file()
 
-    del netrc_file.hosts['git.gigalixir.com'] 
-    del netrc_file.hosts['api.gigalixir.com']
+    if env == 'prod':
+        del netrc_file.hosts['git.gigalixir.com'] 
+        del netrc_file.hosts['api.gigalixir.com']
+    elif env == 'dev':
+        del netrc_file.hosts['localhost']
+    elif env == 'test':
+        del netrc_file.hosts['git.gigalixir.com'] 
+        del netrc_file.hosts['api.gigalixir.com']
+
     with open(fname, 'w') as fp:
         fp.write(netrc_repr(netrc_file))
 
@@ -35,11 +42,20 @@ def update_netrc(email, key, env):
     netrc_file, fname = get_netrc_file()
     
     if env == 'prod':
+        if email is None:
+            # is it safe to assume that the email is always there for us to use?
+            # is it safe to assume the emails are the same for both?
+            (email, _, _) = netrc_file.hosts['api.gigalixir.com']
         netrc_file.hosts['git.gigalixir.com'] = (email, None, key)
         netrc_file.hosts['api.gigalixir.com'] = (email, None, key)
     elif env == 'dev':
+        if email is None:
+            (email, _, _) = netrc_file.hosts['localhost']
         netrc_file.hosts['localhost'] = (email, None, key)
     elif env == 'test':
+        if email is None:
+            # is it safe to assume the emails are the same for both?
+            (email, _, _) = netrc_file.hosts['api.gigalixir.com']
         netrc_file.hosts['git.gigalixir.com'] = (email, None, key)
         netrc_file.hosts['api.gigalixir.com'] = (email, None, key)
     else:
